/*
 * CTU Open Contest 2012
 *
 * Sample solution: Ants
 * Author: Josef Cibulka
 * 
 * Idea: Find the shortest path in the state-space to some state with the prescribed values
 * A single step consists of possibly writing a number and always an operator or '='
 * State = (operator, value on the screen just after the operator was pressed)
 */

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.StringTokenizer; 


public class ladybug
{
	final static int MAXDISP=999;
	final static int OPBUTTON_CNT = 6;

	public static class state
	{
		final static int MAXSTATES=((ladybug.MAXDISP+1)*ladybug.OPBUTTON_CNT);
		
		int disp;
		int opButton;
		int dst;
		int lastIter;

		state(int _disp, int _opButton)
		{
			opButton = _opButton;
			disp = _disp;
			lastIter = -1;
			dst = -1;
		}
		
		// input val followed by nextOpButton
		// val == -1 means no number was input, only the operator
		public state action(int val, int nextOpButton, state allStates[])
		{
			int newDisp = disp;
			int newDst = dst;
			if(val>=0)
				newDst++;
			if(val>=10)
				newDst++;
			if(val>=100)
				newDst++;

			// press nextOpButton (applying the previous opButton) 
			newDisp = ladybug.doOperation(opButton, disp, val);
			// value out of range
			if(newDisp > MAXDISP || newDisp < 0)
				return null;
			// two operators without number in between not allowed
			if(val == -1 && opButton<=3 && nextOpButton<=3) 
				return null;
			newDst++;
			
			int id = getID(newDisp, nextOpButton);

			state newState = allStates[id];
			
			if(newState.lastIter!=ladybug.iter || newState.dst > newDst)
			{
				if(newState.lastIter !=ladybug.iter)
					ladybug.activeStates[ladybug.activeCnt++] = newState;
				// update newState
				newState.lastIter = ladybug.iter;
				newState.dst = newDst;
			}
			else
				newState = null;
			
			return newState;
		}
	}

	public static int iter;

	static boolean numAllowed[];
	static int numbersAllowedCnt;
	static int numbersAllowed[];
	static boolean opAllowed[];

	public static int reqVal;
	public static state states[];
	public static state activeStates[];
	public static int activeCnt, firstActive;

	static int getID(int disp, int opButton)
	{
 		int ret = opButton*(ladybug.MAXDISP+1) + disp;
		return ret;
	}

	
	final static String opChars = "+-*/=C";
	
	static int getOpFromChar(char c)
	{
		switch(c)
		{
			case '+':
				return 0;
			case '-':
				return 1;
			case '*':
				return 2;
			case '/':
				return 3;
			case '=':
				return 4;
			case 'C':
				return 5;
			default:
				assert(false);
				return -1;
		}
	}
	static int doOperation(int op, int val1, int val2)
	{
		switch(op)
		{
			case 0: // +
				if(val2 == -1) 
					return 2*val1;
				else
					return val1+val2;
			case 1: // -
				if(val2 == -1) 
					return val1-val1;
				else
					return val1-val2;
			case 2: // *
				if(val2 == -1) 
					return val1*val1;
				else
					return val1*val2;
			case 3: // /
				if(val2 == -1) 
					return 1;
				else
				{
					if(val2 == 0)
						return 10*MAXDISP; // to cause an error
					else
						return val1/val2;
				}
			case 4: // =
				if(val2 == -1)
					return val1;
				else
					return val2;
			case 5: // C
				if(val2 == -1) 
					return 0;
				else
					return val2;
			default:
				assert(false);
				return -1;
		}
	}

	
	StringTokenizer st = new StringTokenizer("");
	BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
	String nextToken() throws Exception 
	{
		while (!st.hasMoreTokens()) st = new StringTokenizer(input.readLine());
		return st.nextToken();
	}
	int nextInt() throws Exception {
		int ret = Integer.parseInt(nextToken());
		return ret;
	} 
	



	public static void main(String[] args) throws Exception 
	{
		ladybug inst = new ladybug();
		inst.numAllowed = new boolean[10];
		inst.numbersAllowed = new int[MAXDISP+2];
		inst.opAllowed = new boolean[OPBUTTON_CNT];
		inst.states = new state[state.MAXSTATES];
		inst.activeStates = new state[state.MAXSTATES];
		for(int j=0;j<=MAXDISP;j++)
			for(int k=0;k<OPBUTTON_CNT;k++)
		   inst.states[getID(j,k)] = new state(j,k);
			  
		for(int ii=1; ; ii++)
		{
			try {	inst.run(ii);	} catch(Exception e) { return; }
		}
	}





	boolean run(int ii) throws Exception 
	{
		iter = ii;

		String allowed = nextToken();
		if (allowed.length()<=0) 
			throw new Exception();
			
		for(int i=0;i<10;i++)
			numAllowed[i] = false;
		for(int i=0;i<OPBUTTON_CNT;i++)
			opAllowed[i] = false;
		for(int i=0;i<allowed.length();i++)
		{
			char tmpc = allowed.charAt(i);
			if(tmpc>='0' && tmpc<='9')
				numAllowed[tmpc-'0'] = true;
			else
				opAllowed[getOpFromChar(tmpc)] = true;
		}

		reqVal = nextInt();
			
		// determine allowed numbers from allowed numerals
		boolean reqIsAllowed = false;
		numbersAllowedCnt = 0;
		numbersAllowed[numbersAllowedCnt++] = -1;
		if(numAllowed[0]) // 0 must be treated separately
		{
			if(reqVal == 0)
				reqIsAllowed = true;
			numbersAllowed[numbersAllowedCnt++] = 0;
		}
		for(int i=1; i<=MAXDISP; i++)
		{
			int tmp = i;
			while(tmp>0)
			{
				if(!numAllowed[tmp%10])
					break;
				tmp /=10;
			}
			if(tmp == 0) 
			{
				numbersAllowed[numbersAllowedCnt++] = i;
				if(i == reqVal)
					reqIsAllowed = true;
			}
		}
		
		// if we can simply write the number without using any operation, then it is the fastest way
		if(reqIsAllowed)
		{
			int result = 0;
			if(reqVal >= 1) 
				result++;
			if(reqVal >= 10) 
				result++;
			if(reqVal >= 100) 
				result++;
			System.out.println(result);
			return true;
		}
			
		int initState = getID(0,getOpFromChar('C'));
		states[initState].lastIter = iter;
		states[initState].dst = 0;
		activeStates[0] = states[initState];
		firstActive = 0;
		activeCnt = 1;
		
		
		boolean cont = true;
		for(int curDst = 0; cont; curDst++)
		{
			cont = false;
			while(firstActive < activeCnt && activeStates[firstActive].dst < curDst)
				firstActive++;
				
			for(int i = firstActive; i<activeCnt; i++)
			{
				cont = true;
				state curSt = activeStates[i];
				if(curSt.dst == curDst)
				{
					if(curSt.disp == reqVal) // we are done
					{
						System.out.println(curDst);
						return true;
					}
					for(int j=0; j<numbersAllowedCnt; j++)
					{
						int val = numbersAllowed[j];
						for(int op=0; op<OPBUTTON_CNT-1; op++)
							if(opAllowed[op])
								curSt.action(val, op, states);
					}
				}
			}
		}
		
		System.out.println("impossible");
		return true;
	}
}
