/*
 * CTU Open Contest 2012
 *
 * Sample solution: Spider
 * Author: Martin Kacer
 */

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

public class spider {
	StringTokenizer st = new StringTokenizer("");
	BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
	void useLine(String s) { st = new StringTokenizer(s); }
	void useNextLine() throws Exception { useLine(input.readLine()); }
	String nextToken() throws Exception {
		while (!st.hasMoreTokens()) st = new StringTokenizer(input.readLine());
		return st.nextToken();
	}
	int nextInt() throws Exception {
		return Integer.parseInt(nextToken());
	}
	public static void main(String[] args) throws Exception {
		spider instance = new spider();
		while (instance.run()) { /*repeat*/ }
	}
	
	static final int MAXN = 4000;
	static final int INF = Integer.MAX_VALUE / 2;
	
	static class Node {
		final int index;
		List<Node> neighb = new ArrayList<Node>();
		List<Node> skelet = new ArrayList<Node>();
		Node prev;
		int dist = INF; // -1 = closed, INF = not found
		Node(int index) { this.index = index; }
		@Override public String toString() { return "Node[" + index + ",d=" + dist + "]"; }
	}
	
	Node[] nodes;
	int[][] edgemax, edgemin;
	
	int spanTree() {
		int totlen = 0;
		nodes[0].dist = 0; nodes[0].prev = nodes[0];
		for(;;) {
			Node best = null;
			for (Node n : nodes) if (n.dist >= 0) {
				if (best == null || n.dist < best.dist) best = n;
			}
			if (best == null) return totlen;
			if (best.prev == null) return -1; // disconnected
			//System.err.println("  DBG1: " + best + " <- " + best.prev + " / " + edge[best.index][best.prev.index] + "/" + best.dist);
			totlen += best.dist;
			best.dist = -1;
			if (best.prev != best) { // first node self-looped
				best.skelet.add(best.prev); best.prev.skelet.add(best);
			}
			for (Node n : best.neighb) {
				if (edgemin[best.index][n.index] < n.dist) {
					n.dist = edgemin[best.index][n.index];
					n.prev = best;
				}
			}
		}
	}

	int bestLong;
	void dfs(Node first, Node current, Node prev, int maxsofar) {
		if (edgemax[first.index][current.index] > 0) {
			int lng = edgemax[first.index][current.index] + maxsofar;
			if (lng > bestLong) bestLong = lng;
		}
		for (Node n : current.skelet) if (n != prev)
			dfs(first, n, current, Math.max(maxsofar, edgemin[current.index][n.index]));
	}

	boolean run() throws Exception {
		String in = input.readLine();
		if (in == null) return false;
		useLine(in);
		int n = nextInt(), e = nextInt();
		nodes = new Node[n];
		edgemin = new int[n][n]; edgemax = new int[n][n];
		for (int i = 0; i < n; ++i) nodes[i] = new Node(i);
		for (int i = 0; i < e; ++i) {
			int a = nextInt()-1, b = nextInt()-1, len = nextInt();
			nodes[a].neighb.add(nodes[b]); nodes[b].neighb.add(nodes[a]);
			if (edgemin[a][b] == 0 || edgemin[a][b] > len) edgemin[a][b] = edgemin[b][a] = len;
			if (edgemax[a][b] < len) edgemax[a][b] = edgemax[b][a] = len;
		}
		int sptlen = spanTree();
		if (sptlen < 0) {
			System.out.println("disconnected"); return true;
		}
		bestLong = 0;
		for (Node n1 : nodes) dfs(n1, n1, null, 0);
		System.out.println(sptlen - bestLong);
		return true;
	}
}
